Default breakpoint test configurations.
Use these as starting points for testing responsive widgets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
BreakpointTestConfig> - All standard breakpoint configurations.
- desktop → const BreakpointTestConfig
- Desktop configuration (1440px width).
- desktopLarge → const BreakpointTestConfig
- Large desktop configuration (1920px width).
-
extended
→ const List<
BreakpointTestConfig> - Extended configurations including landscape and edge cases.
- mobileLandscape → const BreakpointTestConfig
- Mobile landscape configuration (812px width).
- mobilePortrait → const BreakpointTestConfig
- Mobile portrait configuration (375px width).
- tabletLandscape → const BreakpointTestConfig
- Tablet landscape configuration (1024px width).
- tabletPortrait → const BreakpointTestConfig
- Tablet portrait configuration (768px width).
- tv → const BreakpointTestConfig
- TV configuration (3840px width).
- watch → const BreakpointTestConfig
- Watch configuration (280px width).